import { SmartContractStandard } from "./utils/smartContractStandards.js";
export const generateContractInfo = (contractName, symbol, standard, selectedLibraries) => {
    const name = `${contractName.slice(0, 1).toUpperCase()}${contractName.slice(1)}`;
    let contractInfo;
    switch (standard) {
        case SmartContractStandard.ERC721:
            contractInfo = {
                name,
                symbol: symbol,
                standard: standard,
                isMintable: true,
                isBurnable: false,
                isPausable: false,
                isVotes: false,
                isOwnable: false,
                isRoles: false,
                isAutoIncrement: true,
                isEnumerable: false,
                isURIStorage: false,
            };
            break;
        case SmartContractStandard.ERC20:
            contractInfo = {
                name,
                symbol: symbol,
                standard: standard,
                isMintable: true,
                isBurnable: false,
                isPausable: false,
                isVotes: false,
                isFlashMint: false,
                isSnapshots: false,
                isOwnable: false,
                isRoles: false,
            };
            break;
        case SmartContractStandard.ERC1155:
            contractInfo = {
                name,
                symbol: symbol,
                standard: standard,
                isMintable: true,
                isBurnable: false,
                isPausable: false,
                isVotes: false,
                isOwnable: false,
                isRoles: false,
                supply: true,
            };
            break;
    }
    if (selectedLibraries && selectedLibraries.length) {
        for (const library of selectedLibraries) {
            contractInfo[library] = true;
        }
    }
    if (contractInfo.isOwnable && contractInfo.isRoles) {
        contractInfo.isOwnable = false;
    }
    return contractInfo;
};
//# sourceMappingURL=generateContractInfo.js.map